@@ -85,6 +85,12 @@ class getStripe:
         samplesize[0] += dif
 
         def main_null_calc(chr):
+            background_size = 50000/self.resol
+            background_up = np.floor(background_size / 2)
+            background_down = background_size - background_up
+            background_up = int(background_up)
+            background_down = int(background_down)
+            background_size = int(background_size)
             chr = str(chr)
             np.seterr(divide='ignore', invalid='ignore')
             #c = np.where(chromnames2 == chr)[0]
@@ -136,9 +142,9 @@ class getStripe:
                         x = randval[i]
                         for j in range(0,400):
                             y = x + j
-                            tableft[j, i] = np.mean(mat[(y - 2):(y + 3), (x - 7):(x - 2)])
-                            tabcenter[j, i] = np.mean(mat[(y - 2):(y + 3), (x - 2):(x + 3)])
-                            tabright[j, i] = np.mean(mat[(y - 2):(y + 3), (x + 3):(x + 8)])
+                            tableft[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up-background_size):(x - background_up)])
+                            tabcenter[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up):(x + background_down)])
+                            tabright[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x + background_down):(x + background_down+background_size)])
                     bgleft_temp = np.subtract(tabcenter, tableft)
                     bgright_temp = np.subtract(tabcenter, tabright)
                     bgleft = np.column_stack((bgleft, bgleft_temp))
@@ -154,9 +160,9 @@ class getStripe:
                         x = randval[i]
                         for j in range(0, 400):
                             y = x + j
-                            tableft[j, i] = np.mean(mat[(y - 2):(y + 3), (x - 7):(x - 2)])
-                            tabcenter[j, i] = np.mean(mat[(y - 2):(y + 3), (x - 2):(x + 3)])
-                            tabright[j, i] = np.mean(mat[(y - 2):(y + 3), (x + 3):(x + 8)])
+                            tableft[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up - background_size):(x - background_up)])
+                            tabcenter[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up):(x + background_down)])
+                            tabright[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x + background_down):(x + background_down+background_size)])
                     bgleft_temp = np.subtract(tabcenter, tableft)
                     bgright_temp = np.subtract(tabcenter, tabright)
                     del mat
@@ -193,9 +199,9 @@ class getStripe:
                     x = randval[i]
                     for j in range(0, 400):
                         y = x + j
-                        tableft[j, i] = np.mean(mat[(y - 2):(y + 3), (x - 7):(x - 2)])
-                        tabcenter[j, i] = np.mean(mat[(y - 2):(y + 3), (x - 2):(x + 3)])
-                        tabright[j, i] = np.mean(mat[(y - 2):(y + 3), (x + 3):(x + 8)])
+                        tableft[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up - background_size):(x - background_up)])
+                        tabcenter[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x - background_up):(x + background_down)])
+                        tabright[j, i] = np.mean(mat[(y - background_up):(y + background_down), (x + background_down):(x + background_down+background_size)])
                 bgleft_temp = np.subtract(tabcenter, tableft)
                 bgright_temp = np.subtract(tabcenter, tabright)
                 del mat
@@ -219,8 +225,45 @@ class getStripe:
         print('Elapsed time for background estimation: ' + str(np.round((time.time() - t_background_start) / 60, 3)) + ' min')
         return bgleft, bgright
 
+    def getMean(self, df, mask='0'):
+
+        if mask != '0':
+            mask = mask.split(':')
+            mask_chr = mask[0]
+            mask_start = int(mask[1].split('-')[0])
+            mask_end = int(mask[1].split('-')[1])
+
+        def iterate_idx(i):
+            np.seterr(divide='ignore', invalid='ignore')
+            chr = df['chr'].iloc[i]
+            x_start_index = int(df['pos1'].iloc[i])
+            x_end_index = int(df['pos2'].iloc[i])
+            y_start_index = int(df['pos3'].iloc[i])
+            y_end_index = int(df['pos4'].iloc[i])
+            region1=str(chr)+':'+str(y_start_index)+'-'+str(y_end_index)
+            region2=str(chr)+':'+str(x_start_index)+'-'+str(x_end_index)
+            center = self.unbalLib.fetch(region1, region2)
+
+            centerm = np.nanmean(center)
+            centersum=np.nansum(center)
+            return i,centerm,centersum
+
+        # Scoring
+        ### Sobel-like operators
+        nrows=len(df)
+        result = Parallel(n_jobs=self.core)(delayed(iterate_idx)(i) for i in tqdm(range(nrows)))
+        listM = [0 for x in range(0,nrows)]
+        listS = [0 for x in range(0, nrows)]
+        for r in range(len(result)):
+            i,MEAN,SUM = result[r]
+            listM[i] = MEAN
+            listS[i] = SUM
+        return listM,listS
 
     def pvalue(self, bgleft, bgright, df):
+        background_size = 50000 / self.resol
+        background_size = int(background_size)
+
         np.seterr(divide='ignore', invalid='ignore')
         PVAL = []
         dfsize = len(df)
@@ -232,8 +275,8 @@ class getStripe:
             pos2 = df['pos2'].iloc[i]
             pos3 = df['pos3'].iloc[i]
             pos4 = df['pos4'].iloc[i]
-            leftmost = pos1 - 5 * self.resol
-            rightmost = pos2 + 5 * self.resol
+            leftmost = pos1 - background_size * self.resol
+            rightmost = pos2 + background_size * self.resol
             if leftmost < 1:
                 leftmost = 1
             if rightmost > chrLen:
@@ -241,9 +284,9 @@ class getStripe:
             cd1 = chr + ":" + str(leftmost) + "-" + str(rightmost)
             cd2 = chr + ":" + str(pos3) + "-" + str(pos4)
             mat = self.unbalLib.fetch(cd2, cd1)
-            mat_center = mat[:, 5:-5]
-            mat_left = mat[:, :5]
-            mat_right = mat[:, -5:]
+            mat_center = mat[:, background_size:(-1*background_size)]
+            mat_left = mat[:, :background_size]
+            mat_right = mat[:, (-1*background_size):]
 
             mat_center = nantozero(mat_center)
             mat_left = nantozero(mat_left)
@@ -365,6 +408,9 @@ class getStripe:
         return PVAL
 
     def scoringstripes(self, df, mask='0'):
+        background_size = 50000/self.resol
+        background_size = int(background_size)
+
         if mask != '0':
             mask = mask.split(':')
             mask_chr = mask[0]
@@ -381,8 +427,8 @@ class getStripe:
             y_start_index = int((df['pos3'].iloc[i] - 1) / self.resol)
             y_end_index = int(df['pos4'].iloc[i] / self.resol)
 
-            leftmost = x_start_index - 5
-            rightmost = x_end_index + 5
+            leftmost = x_start_index - background_size
+            rightmost = x_end_index + background_size
             if leftmost < 1:
                 leftmost = 1
             if rightmost > normmat.shape[0]:
@@ -399,6 +445,9 @@ class getStripe:
             leftm = np.nanmean(left, axis=1)
             rightm = np.nanmean(right, axis=1)
 
+            centerTotal = np.nansum(center)
+            centerMean = np.nanmean(center)
+
             g_xl = stats.elementwise_product_sum(K_xl, leftm, centerm)
             g_xr = stats.elementwise_product_sum(K_xr, centerm, rightm)
             g_y = stats.elementwise_product_sum(K_y, leftm, centerm, rightm)
@@ -406,11 +455,14 @@ class getStripe:
             diff = [a - b for a, b in zip(g_x, g_y)]
             avgdiff = np.nanmean(diff)
             g = np.nanmedian(centerm) * avgdiff
-            return i,g
+            return i,g,centerMean, centerTotal
 
         # Scoring
         ### Sobel-like operators
         listg = [0 for x in range(df.shape[0])]
+        listMean = [0 for x in range(df.shape[0])]
+        listTotal = [0 for x in range(df.shape[0])]
+
         K_xl = np.array([[-1, 1], [-2, 2], [-1, 1]])
         K_xr = np.array([[1, -1], [2, -2], [1, -1]])
         K_y = np.array([[1, 2, 1], [0, 0, 0], [-1, -2, -1]])
@@ -434,9 +486,11 @@ class getStripe:
             result = Parallel(n_jobs=self.core)(delayed(iterate_idx)(i,is_mask) for i in tqdm(idx))
             del normmat
             for r in range(len(result)):
-                i,g = result[r]
+                i,g,cM,cT = result[r]
                 listg[i] = g
-        return listg
+                listMean[i] = cM
+                listTotal[i] = cT
+        return listg,listMean,listTotal
 
     def extract(self, mp, bgleft, bgright):
         np.seterr(divide='ignore', invalid='ignore')
@@ -871,6 +925,7 @@ def extract_from_matrix(matrix, x_start, x_end, y_start, y_end, mask_x_start = 0
     x = [i for i in x if i not in x_mask]
     xlen = len(x)
     y = list(range(y_start, y_end))
+    y = [i for i in y if i not in x_mask]
     ylen = len(y)
     result = np.empty((ylen, xlen), dtype=float)
     for i in range(ylen):
